---
name: '🥳 发布插件'
title: "[Plugin] 插件名"
about: 提交插件到插件市场
labels: [ "plugin-publish" ]
assignees: ''

---

欢迎发布插件到插件市场！

## 插件基本信息

请将插件信息填写到下方的 Json 代码块中。`tags`（插件标签）和 `social_link`（社交链接）选填。

```json
{
  "name": "插件名",
  "desc": "插件介绍",
  "author": "作者名",
  "repo": "插件仓库链接",
  "tags": [],
  "social_link": ""
}
```

## 检查

- [ ] 我的插件经过完整的测试
- [ ] 我的插件不包含恶意代码
- [ ] 我已阅读并同意遵守该项目的 [行为准则](https://docs.github.com/zh/site-policy/github-terms/github-community-code-of-conduct)。
